#define Main_H


//*****************************************************************************************
// Declaration des Entetes et variables
//*****************************************************************************************
	#include	"../h/Main.h"
//*****************************************************************************************





//******************************************************************************
// Bit de configurations du microcontroleur
//******************************************************************************
#pragma config PLLDIV 	= 1
#pragma config CPUDIV 	= OSC1_PLL2
#pragma config USBDIV 	= 2
#pragma config FOSC 	= HSPLL_HS
#pragma config PWRT 	= ON					// Activation du Power On reset
#pragma config BOR 		= ON					// dtection d'une chute de tension
#pragma config BORV 	= 0						// dtection d'une chute de tension en dessous de 2,8 V
#pragma config WDT 		= ON					// Chien de garde activ
#pragma config WDTPS 	= 512					// Temps d'environ 2.048 s = 4ms * 512
#pragma config MCLRE 	= ON					// MCLR configurer comme Bit de RESET
#pragma config LPT1OSC 	= OFF
#pragma config PBADEN 	= OFF					// Port B en digital lors du Reset
#pragma config STVREN 	= OFF
#pragma config CCP2MX 	= ON					// Valide RC1 pour le PWM
#pragma config LVP 		= OFF					// inhibition de la programmation basse tension
#pragma config DEBUG 	= ON					// Sort du mode Debug
#pragma config XINST 	= OFF
#pragma config VREGEN 	= ON					// Valide l'alimentation du module USB
//***********************************************************************************






//*******************************************************************************************************
// Initialisation des variables de correction
//*******************************************************************************************************
void InitVariableCorrection(void)
{
	// Initialisation de la Correction de la mesure de Tension Alim15 : CorrectionAlim15
		CorrectionAlim15 = CorrectionAlim15Def;

	// Initialisation de la Correction de la mesure de Tension Accu3 : CorrectionAccu3
		CorrectionAccu3 = CorrectionAccu3Def;

	// Initialisation de la Correction de la mesure de Tension Accu2 : CorrectionAccu2
		CorrectionAccu2 = CorrectionAccu2Def;

	// Initialisation de la Correction de la mesure de Tension Accu1 : CorrectionAccu1
		CorrectionAccu1 = CorrectionAccu1Def;

	// Initialisation de la Correction de la mesure de Tension Accu4 : CorrectionAccu4
		CorrectionAccu4 = CorrectionAccu4Def;

	// Initialisation de la Correction de la mesure du courant : CorrectionCourant
		CorrectionCourant = CorrectionCourantDef;
}
//*******************************************************************************************************














//**********************************************************************************************
// Acquisition numerique de toutes les tensions
//**********************************************************************************************
void AcquisitionNumerique(void)
{
	if(NumAcquisition < 8)
    {
		if(AutoriseLed) 	LedVerte = 1;
        AcquisitionTension();								// Mesure de toutes les tensions - Fichier : Adc.c
        if(AutoriseLed) 	LedVerte = 0;
	}
	else
	{
        if(NumAcquisition == 8)
        {
			if(AutoriseLed) 	LedRouge = 1;
			FiltrageEtSauvegarde();							// Fichier : BatFiltrageNum.c
		
			CalculTensionAccu();							// Fichier : BatCalcule.c
		
			if((PremiereAcquisition > 20) & (AutoriseLed == 1))
			{
				ChercheAccuCharge();						// Fichier : BatCalcule.c
			}
		
			SauvegardeTensionAccu();						// Fichier : BatCalcule.c
			if(AutoriseLed) 	LedRouge = 0;
			NumAcquisition		= 9;
		}
	}
}
//**********************************************************************************************






//**********************************************************************************************
// Initialisation gnrale
//**********************************************************************************************
void InitGeneral(void)
{
	InitVariableCorrection();			// Initialisation des variables de correction
	BatInitPwm();						// Initialisation du PWM pour raliser la tension de consigne
	BatInitAdc();						// Initialisation de la conversion AN
	BatInitTimer0();					// Initialisation du Timer 0 pour faire les conversion AN
	BatPort();							// Initialisation des entres - sorties
	
	CoefAmplificateur	= CoefAmplificateurDef;
	CoefMoyenneur		= CoefMoyenneurDef;
	OffsetCharge		= OffsetChargeDef;
	OffsetChargeElt		= OffsetChargeEltDef;

	Charge 				= 1;			// Voir fichier 	Main.h
	BatChangePwm(0);					// Voir fichier 	BatPwm.c
	BatInitVariableFiltrage();			// Voir fichier 	BatFiltrageNum.c

	// Autorisations des interruptions
	RCONbits.IPEN 		= 1;			// Valide les niveaux d'interruption
	INTCONbits.GIE 		= 1;			// Autorisation interruptions globales
	INTCONbits.PEIE 	= 1;			// Validation interruptions des periphriques
}
//**********************************************************************************************











//**********************************************************************************************
// Programme principal 
//**********************************************************************************************
void main(void)
{
    mInitializeUSBDriver();         // See usbdrv.h
    InitGeneral();
    
    while(1)
    {
        USBTasks();         		// USB Tasks pour USB Fichier : main2550.c
		LecturePortUSB();			// Voir fichier PortUSB.c
		AcquisitionNumerique();		// Voir fichier Main.c
        ClrWdt();					// Reinitialisation du chien de garde
	}							
}
//**********************************************************************************************









