//*****************************************************************************************
// Declaration des Entetes et variables
//*****************************************************************************************
	#include	"../h/Main.h"
//*****************************************************************************************









//**********************************************************************************************
// Lecture de la reception sur port USB
//**********************************************************************************************
void LecturePortUSB(void)
{
    static unsigned char 	i;
    static unsigned char 	InputBuffer[8];
    static unsigned int 	Tmp;
	
	// Test de reception d'octet pour dtecter l'interface connecte
    if(getsUSBUSART(InputBuffer,8) != 0)
    {
		if(InputBuffer[0] == 0xFF)
	    {
			RxBuffer[0] = 'T';
			RxBuffer[1] = 'R';
			RxBuffer[2] = 'A';
			RxBuffer[3] = 'I';
			RxBuffer[4] = 'N';
			RxBuffer[5] = 0x00;
		}
		
		
		if(InputBuffer[0] == 0x10)			// Recupere la conversion Analogique - Numerique
		{									// Dure de l'opration : 123 Cycles instructions
			for(i=0; i<= NbTotalOctetUSB; i++)
			{
				RxBuffer[i] = ResultatConv[i];
			}
			i = NbTotalOctetUSB + 1;
			RxBuffer[i] = 0x00;
		}
		
		if(InputBuffer[0] == 0x11)			// Changement du Pwm Modification de la tension de consigne
		{
			Tmp = InputBuffer[1] * 256;
			Tmp = Tmp + InputBuffer[2] * 16;
			Tmp = Tmp + InputBuffer[3];
			BatChangePwm(Tmp);
			BatInitVariableFiltrage();
			RxBuffer[1] = 'P';
			RxBuffer[2] = 0x00;
		}
		
		if(InputBuffer[0] == 0x12)			// Changement de la tension de ref du conv Anal-Num
		{
			if(InputBuffer[1] == 0x1)		// Tension de Ref = 5 V - Vref = VDD
			{
				ADCON1bits.VCFG0 = 0;
			}
			
			if(InputBuffer[1] == 0x2)		// Tension de Ref = 4,096 V - Vref = AN3
			{
				ADCON1bits.VCFG0 = 1;
			}
			RxBuffer[1] = 'V';
			RxBuffer[2] = 0x00;
		}
		
		if(InputBuffer[0] == 0x13)			// Mode Chargeur ou Dechargeur
		{
			if(InputBuffer[1] == 0x1)		// Mode Chargeur
			{
				Charge 		= 1;
				RxBuffer[0] = 'C';
				RxBuffer[1] = 'H';
				RxBuffer[2] = 'A';
				RxBuffer[3] = 'R';
				RxBuffer[4] = 'G';
				RxBuffer[5] = 0x00;
			}
			
			if(InputBuffer[1] == 0x2)		// Mode Dchargeur
			{
				Charge 		= 0;
				RxBuffer[0] = 'D';
				RxBuffer[1] = 'E';
				RxBuffer[2] = 'C';
				RxBuffer[3] = 'H';
				RxBuffer[4] = 'A';
				RxBuffer[5] = 0x00;
			}
			BatInitVariableFiltrage();
		}
		

		if(InputBuffer[0] == 0x14)			// Lecture du Mode Chargeur ou Dechargeur
		{
			LectureRegistres();
		}


		if(InputBuffer[0] == 0x17)			// Init pour la charge ou decharge
		{
			BatInitVariableFiltrage();
		}


		if(InputBuffer[0] == 0x18)			// Lecture des coefficients
		{
			LectureCoefficient();			// Ampli, Moyenneur, offset, etc...
			RxBuffer[16] = 0x00;
		}


		InputBuffer[0] = 0x00;
		EnvoiData = 1;
	}
		 
	if(EnvoiData == 1)
	{
		if(mUSBUSARTIsTxTrfReady())
		{
			putsUSBUSART(RxBuffer);
			EnvoiData = 0;
		}
	}
}
//**********************************************************************************************






//**********************************************************************************************
// Lecture des registres du chargeur
//**********************************************************************************************
void LectureRegistres(void)
{
    static unsigned char i, n;
	
	
	if(Charge == 0x1)				// Lecture Mode Chargeur
	{
		RxBuffer[0] = 'C';
	}
	else
	{
		RxBuffer[0] = 'D';
	}
	
	if(ADCON1bits.VCFG0 == 0)				// Lecture de la reference de tension pour ADC
	{
		RxBuffer[1] = '5';
	}
	else
	{
		RxBuffer[1] = '4';
	}
	
	n = NbTotalOctetUSB + 2;
	for(i=2; i<= n; i++)
	{
		RxBuffer[i] = ResultatConv[i-2];
	}
	
	n = n + 1;
	RxBuffer[n] = 0x00;
}
//**********************************************************************************************









//**********************************************************************************************
// Lecture des registres du chargeur
//**********************************************************************************************
void LectureCoefficient(void)
{
    static unsigned long Tmp;

			Tmp = (CoefAmplificateur >> 12);
			RxBuffer[0] = Tmp + 0x30;
			
			Tmp = (CoefAmplificateur >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[1] = Tmp + 0x30;
			
			Tmp = (CoefAmplificateur >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[2] = Tmp + 0x30;
			
			RxBuffer[3] = (CoefAmplificateur & 0x000F);
			RxBuffer[3] = RxBuffer[3] + 0x30;
			

			Tmp = (CoefMoyenneur >> 12);
			RxBuffer[4] = Tmp + 0x30;
			
			Tmp = (CoefMoyenneur >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[5] = Tmp + 0x30;
			
			Tmp = (CoefMoyenneur >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[6] = Tmp + 0x30;
			
			RxBuffer[7] = (CoefMoyenneur & 0x000F);
			RxBuffer[7] = RxBuffer[7] + 0x30;
			

			Tmp = (OffsetCharge >> 12);
			RxBuffer[8] = Tmp + 0x30;
			
			Tmp = (OffsetCharge >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[9] = Tmp + 0x30;
			
			Tmp = (OffsetCharge >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[10] = Tmp + 0x30;
			
			RxBuffer[11] = (OffsetCharge & 0x000F);
			RxBuffer[11] = RxBuffer[11] + 0x30;
			

			Tmp = (OffsetChargeElt >> 12);
			RxBuffer[12] = Tmp + 0x30;
			
			Tmp = (OffsetChargeElt >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[13] = Tmp + 0x30;
			
			Tmp = (OffsetChargeElt >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[14] = Tmp + 0x30;
			
			RxBuffer[15] = (OffsetChargeElt & 0x000F);
			RxBuffer[15] = RxBuffer[15] + 0x30;
}
//**********************************************************************************************



