//**********************************************************************************************
// Declaration des entetes et prototypes
//**********************************************************************************************
	#include 	"..\h\Main.h"      		// Required
//**********************************************************************************************






//**********************************************************************************
// Configuration du convetisseur Analogique Numerique
//**********************************************************************************
void BatInitAdc(void)
{
	BatInitVariableFiltrage();
	
	// Selection de la voie 0
	ADCON0bits.CHS3 	= 0;		// 
	ADCON0bits.CHS2 	= 0;		//  
	ADCON0bits.CHS1 	= 0;		//  
	ADCON0bits.CHS0 	= 0;		//  Selection de la voie 0
	VoieProchaineMesure = 0;
	
	ADCON1bits.VCFG1 	= 0;
	ADCON1bits.VCFG0 	= 1;		// Ref pour convertisseur sur AN3 par composant exterieur
	
	// RA0, RA1, RA2, RA3, RA5, RB1, RB2 et RB3 en analogique - le reste en numerique
	ADCON1bits.PCFG3 	= 0;
	ADCON1bits.PCFG2 	= 1;
	ADCON1bits.PCFG1 	= 0;
	ADCON1bits.PCFG0 	= 0;
	

	// Realisation du temps Tad = 1.6 s avec quartz 12 MHz et PLL soit Tcyc = 100 ns
	ADCON2bits.ADCS2 	= 1;
	ADCON2bits.ADCS1 	= 1;
	ADCON2bits.ADCS0 	= 0;
	
	ADCON2bits.ADFM 	= 1;		// Justification  droite du resultat de conversion
	
	ADCON2bits.ACQT2 	= 1;
	ADCON2bits.ACQT1 	= 1;
	ADCON2bits.ACQT0 	= 1;		// 8 Tad pour l'acquisition du signal Analogique
	
	ADCON0bits.ADON 	= 1;		// Marche du convertisseur Anal Num
	
	IPR1bits.ADIP 		= 0;		// Interrupt non prioritaire
	PIR1bits.ADIF 		= 0;		// Init du bit de depassement
	PIE1bits.ADIE 		= 0;		// Interdiction interruption du convertisseur AN
}
//**********************************************************************************





//**********************************************************************************
// Calcul du courant max pour la charge ou la decharge des accus
// Imax = dT / (Rth * Vce) on choisit dT = 55 C - Rth = 8C/W
// Imax = 55 * 1024 / (8 * 5 * Vce) = 1408 / Vce
// Imax = 1408 * 1024 * CoefAmplificateur / (4 * Vref * Vaccu4MoyAmpli)
//**********************************************************************************
void BatCalculeCourantMax(void)
{
	if(ADCON1bits.VCFG0 == 1)				// Vref = 4.096V
	{
		Imax		= 88000 * CoefAmplificateur;
		Imax		= Imax / Vaccu4MoyAmpli;
	}
	else									// Vref = 5V
	{
		Imax		= 360448 * CoefAmplificateur;
		Imax		= Imax / 5;
		Imax		= Imax / Vaccu4MoyAmpli;
	}
	
	if(Ipwm > Imax)
	{
		BatChangePwm(Imax);
	}
}
//**********************************************************************************




//**********************************************************************************
// Choix de la voie de conversion pour la conversion Analogique Numrique
//**********************************************************************************
void BatSelectionVoieAdc(unsigned char Voie)
{
	static unsigned char T;
	
	
	// Selection de la voie de conversion Analogique Numerique
	T = (Voie << 2);
	ADCON0 = (ADCON0 & 0xC3);
	ADCON0 = (ADCON0 | T);
	
//	for(T=0;T<50;T++);		// Temporisation pour stabiliser le signal
}
//**********************************************************************************




//**********************************************************************************
// Lance et recupere le resultat de la conversion Analogique Numerique
//**********************************************************************************
unsigned int ConversionAdc(void)
{
	PIR1bits.ADIF = 0;				// Init du bit de fin de conversion
	ADCON0bits.GO = 1;				// Lance la conversion

	while(ADCON0bits.GO == 1);
	ResulConvAN = ADRESH;
	ResulConvAN = ResulConvAN << 8;
	ResulConvAN = ResulConvAN + ADRESL;
	PIR1bits.ADIF = 0;
	
	return(ResulConvAN);
}
//**********************************************************************************




//**********************************************************************************
// Correction de la Conversion Analogique - Numerique
//**********************************************************************************
unsigned int BatCorrigeConversion(unsigned int Correction)
{
	static unsigned long Tmp;
	

	Tmp		= ResulConvAN;
	Tmp 	= Tmp * Correction;
	Tmp		= Tmp / 10000;
	return(Tmp);
}
//**********************************************************************************





//**********************************************************************************
// Acquisition des tensions accu, temperature et courant
//**********************************************************************************
void AcquisitionTension(void)
{
	static unsigned long Tmp;
	
	switch(NumAcquisition)
	{
		case 1:
		{	
			Vaccu1				= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesAccu2);
			break;
		}
		
		case 2:
		{	
			Vaccu2				= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesAccu1);
			Velement			= (Vaccu2 - Vaccu1);
			Velement			= Velement << 2;
			break;
		}
		
		case 3:
		{	
			Vaccu3				= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesAccu4);
			break;
		}
		
		case 4:
		{	
			Vaccu4				= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesVAlim15V);
			break;
		}
		
		case 5:
		{	
			Valim15				= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesAccu1);
			break;
		}
		
		case 6:
		{	
			Vcourant			= ConversionAdc();
			NumAcquisition		= NumAcquisition + 1;
			BatSelectionVoieAdc(VoieMesTempAccu);
			break;
		}
		
		default:
		{
			BatSelectionVoieAdc(VoieMesAccu1);
			NumAcquisition		= 1;
			break;
		}
	}
}
//**********************************************************************************





//**********************************************************************************
// Conversion pour port USB
//**********************************************************************************
void BatSauvegardeConvPourUSB(unsigned long TensionAconvertir)
{
	static unsigned long Quotient;
	static unsigned long Dividende;
	static unsigned long Reste;
	
	
	//Dividende					= TensionAconvertir / CoefCorrecteur;
	Dividende					= TensionAconvertir;
	Quotient					= Dividende >> 7;
	Reste						= TensionAconvertir - (Quotient * 128);
	ResultatConv[NumSauvegarde] = Reste + 10;					// Poids faible
	
	NumSauvegarde++;
	Dividende					= Quotient >> 7;
	Reste						= Quotient - (Dividende * 128);
	ResultatConv[NumSauvegarde] = Reste + 10;	
	
	NumSauvegarde++;
	ResultatConv[NumSauvegarde] = Dividende + 10;				// Poids fort

	NumSauvegarde++;
}
//**********************************************************************************


