//**********************************************************************************************
// Declaration des entetes et prototypes
//**********************************************************************************************
	#include 	"..\h\Main.h"      		// Required
//**********************************************************************************************





//**********************************************************************************************
// Definition des variables en EEPROM
//**********************************************************************************************
//    ADRESSE EEPROM		VARIBLES CORRESPONDANTES
//		00 et 01				CorrectionAlim15
//		02 et 03				CorrectionAccu3
//		04 et 05				CorrectionAccu2
//		06 et 07				CorrectionAccu1
//		08 et 09				CorrectionAccu4
//		0A et 0B				CorrectionCourant
//**********************************************************************************************







//*******************************************************************************************************
// Ecriture en EEPROM
//*******************************************************************************************************
void Ecrit_EEPROM(unsigned char Adr_EEPROM, unsigned char Data_EEPROM)
{
	EEADR 				= Adr_EEPROM;
	EEDATA 				= Data_EEPROM;
	
	EECON1bits.EEPGD 	= 0;			// Pointe sur la mmoire Donne
	EECON1bits.CFGS 	= 0;			// Accede  la mmoire EEPROM
	EECON1bits.WREN 	= 1;			// Valide l'criture en EEPROM
	
	INTCONbits.GIE 		= 0;			// Interdit toutes les interruptions*
	EECON2 				= 0x55;
	EECON2 				= 0xAA;
	
	EECON1bits.WR 		= 1;			// Debut de l'ecriture
	
	while(EECON1bits.WR == 1);			// test de la fin d'ecriture
	EECON1bits.WREN 	= 0;			// Interdit l'criture en EEPROM
	
	INTCONbits.GIE 		= 1;			// Autorise toutes les interruptions*
}
//*******************************************************************************************************




//*******************************************************************************************************
// Lecture en EEPROM
//*******************************************************************************************************
unsigned char Lit_EEPROM(unsigned char Adr_EEPROM)
{
	EEADR 				= Adr_EEPROM;
	
	EECON1bits.EEPGD 	= 0;			// Pointe sur la mmoire Donne
	EECON1bits.CFGS 	= 0;			// Accede  la mmoire EEPROM
	EECON1bits.RD 		= 1;			// Debut de l'ecriture
	
	return(EEDATA);
}
//*******************************************************************************************************






//*******************************************************************************************************
// Initialisation des variables presentes en EEPROM
//*******************************************************************************************************
void InitVariableEeprom(void)
{
	static unsigned char Tampon;
	
	// Initialisation de la Correction de la mesure de Tension Alim15 : CorrectionAlim15
	Tampon = Lit_EEPROM(AdrAlim15H);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionAlim15 = CorrectionAlim15Def;
	}
	else
	{
		CorrectionAlim15 = Tampon;
		CorrectionAlim15 = CorrectionAlim15 << 8;
		Tampon = Lit_EEPROM(AdrAlim15B);
		CorrectionAlim15 = CorrectionAlim15 + Tampon;
	}
	
	

	// Initialisation de la Correction de la mesure de Tension Accu3 : CorrectionAccu3
	Tampon = Lit_EEPROM(AdrAccu3H);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionAccu3 = CorrectionAccu3Def;
	}
	else
	{
		CorrectionAccu3 = Tampon;
		CorrectionAccu3 = CorrectionAccu3 << 8;
		Tampon = Lit_EEPROM(AdrAccu3B);
		CorrectionAccu3 = CorrectionAccu3 + Tampon;
	}


	// Initialisation de la Correction de la mesure de Tension Accu2 : CorrectionAccu2
	Tampon = Lit_EEPROM(AdrAccu2H);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionAccu2 = CorrectionAccu2Def;
	}
	else
	{
		CorrectionAccu2 = Tampon;
		CorrectionAccu2 = CorrectionAccu2 << 8;
		Tampon = Lit_EEPROM(AdrAccu2B);
		CorrectionAccu2 = CorrectionAccu2 + Tampon;
	}



	// Initialisation de la Correction de la mesure de Tension Accu1 : CorrectionAccu1
	Tampon = Lit_EEPROM(AdrAccu1H);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionAccu1 = CorrectionAccu1Def;
	}
	else
	{
		CorrectionAccu1 = Tampon;
		CorrectionAccu1 = CorrectionAccu1 << 8;
		Tampon = Lit_EEPROM(AdrAccu1B);
		CorrectionAccu1 = CorrectionAccu1 + Tampon;
	}



	// Initialisation de la Correction de la mesure de Tension Accu4 : CorrectionAccu4
	Tampon = Lit_EEPROM(AdrAccu4H);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionAccu4 = CorrectionAccu4Def;
	}
	else
	{
		CorrectionAccu4 = Tampon;
		CorrectionAccu4 = CorrectionAccu4 << 8;
		Tampon = Lit_EEPROM(AdrAccu4B);
		CorrectionAccu4 = CorrectionAccu4 + Tampon;
	}



	// Initialisation de la Correction de la mesure du courant : CorrectionCourant
	Tampon = Lit_EEPROM(AdrCourantH);
	if(Tampon == 0xFF)				// Eeprom non configur
	{
		CorrectionCourant = CorrectionCourantDef;
	}
	else
	{
		CorrectionCourant = Tampon;
		CorrectionCourant = CorrectionCourant << 8;
		Tampon = Lit_EEPROM(AdrCourantB);
		CorrectionCourant = CorrectionCourant + Tampon;
	}
}
//*******************************************************************************************************






