//*****************************************************************************************
// Declaration des Entetes et variables
//*****************************************************************************************
	#include	"../h/Main.h"
//*****************************************************************************************









//**********************************************************************************************
// Lecture de la reception sur port USB
//**********************************************************************************************
void LecturePortUSB(void)
{
    static unsigned char 	i;
    static unsigned char 	InputBuffer[8];
    static unsigned char 	Val[8];
    static unsigned int 	Tmp;
    static unsigned long 	t;
	
	// Test de reception d'octet pour dtecter l'interface connecte
    if(getsUSBUSART(InputBuffer,8) != 0)
    {
		if(InputBuffer[0] == 0xFF)
	    {
			RxBuffer[0] = 'T';
			RxBuffer[1] = 'R';
			RxBuffer[2] = 'A';
			RxBuffer[3] = 'I';
			RxBuffer[4] = 'N';
			RxBuffer[5] = 0x00;
		}
		
		
		if(InputBuffer[0] == 0x10)			// Recupere la conversion Analogique - Numerique
		{									// Dure de l'opration : 123 Cycles instructions
			for(i=0; i<= NbTotalOctetUSB; i++)
			{
				RxBuffer[i] = ResultatConv[i];
			}
			i = NbTotalOctetUSB + 1;
			RxBuffer[i] = 0x00;
		}
		
		if(InputBuffer[0] == 0x11)			// Changement du Pwm Modification de la tension de consigne
		{									// donc du courant de charge ou decharge
			Tmp = InputBuffer[1] * 256;
			Tmp = Tmp + InputBuffer[2] * 16;
			Tmp = Tmp + InputBuffer[3];
			BatChangePwm(Tmp);
			BatInitVariableFiltrage();
			RxBuffer[0] = 'V';
			RxBuffer[1] = 'P';
			RxBuffer[2] = 0x00;
		}
		
		if(InputBuffer[0] == 0x12)			// Changement de la tension de ref du conv Anal-Num
		{
			if(InputBuffer[1] == 0x1)		// Tension de Ref = 5 V - Vref = VDD
			{
				ADCON1bits.VCFG0 = 0;
			}
			
			if(InputBuffer[1] == 0x2)		// Tension de Ref = 4,096 V - Vref = AN3
			{
				ADCON1bits.VCFG0 = 1;
			}
			RxBuffer[0] = 'V';
			RxBuffer[1] = 'V';
			RxBuffer[2] = 0x00;
		}
		
		if(InputBuffer[0] == 0x13)			// Mode Chargeur ou Dechargeur
		{
			if(InputBuffer[1] == 0x1)		// Mode Chargeur
			{
				Charge 		= 1;
				RxBuffer[0] = 'C';
				RxBuffer[1] = 'H';
				RxBuffer[2] = 'A';
				RxBuffer[3] = 'R';
				RxBuffer[4] = 'G';
				RxBuffer[5] = 0x00;
			}
			
			if(InputBuffer[1] == 0x2)		// Mode Dchargeur
			{
				Charge 		= 0;
				RxBuffer[0] = 'D';
				RxBuffer[1] = 'E';
				RxBuffer[2] = 'C';
				RxBuffer[3] = 'H';
				RxBuffer[4] = 'A';
				RxBuffer[5] = 0x00;
			}
			BatInitVariableFiltrage();
		}
		

		if(InputBuffer[0] == 0x14)			// Lecture du Mode Chargeur ou Dechargeur
		{
			LectureRegistres();
		}



		if(InputBuffer[0] == 0x15)			// Sauvegarde en EEPROM
		{
			Val[1]	= InputBuffer[1];
			Val[2]	= InputBuffer[2];
			Val[3]	= InputBuffer[3];
			Val[4]	= InputBuffer[4];
			Val[5]	= InputBuffer[5];
			Val[6]	= InputBuffer[6];
			Val[7]	= InputBuffer[7];
			SauvegardeEnEeprom(Val);
			
			InitVariableEeprom();				// Initialisation des variables de correction
			
			RxBuffer[0] = 'E';
			RxBuffer[1] = 'E';
			RxBuffer[2] = 'P';
			RxBuffer[3] = 'R';
			RxBuffer[4] = 'O';
			RxBuffer[5] = 0x00;
		}


		if(InputBuffer[0] == 0x16)			// Lecture de la EEPROM
		{
			LectureEnEeprom();
			RxBuffer[20] = 0x00;
		}


		if(InputBuffer[0] == 0x17)			// Init pour la charge ou decharge
		{
			BatInitVariableFiltrage();
		}


		if(InputBuffer[0] == 0x18)			// Lecture des coefficients
		{
			LectureCoefficient();			// Ampli, Moyenneur, offset, etc...
			RxBuffer[16] = 0x00;
		}

		
		if(InputBuffer[0] == 0x19)			// Lecture des coefficients Amplificateur
		{
			LectureCoefAmpli();				// Coef Amplificateur
			//RxBuffer[16] = 0x00;
		}

		
		if(InputBuffer[0] == 0x20)			// Recuperation des coef Ampli 
		{
			i = InputBuffer[1] - 9;
			CoeffAmpl[i] = InputBuffer[2] - 10;								// Coef Amplificateur
			CoeffAmpl[i] = CoeffAmpl[i] * 4096;
			t = InputBuffer[3] - 10;
			t = t * 64;
			CoeffAmpl[i] = CoeffAmpl[i] + t;								// Coef Amplificateur
			t = InputBuffer[4] - 10;
			CoeffAmpl[i] = CoeffAmpl[i] + t;
			//BatInitCoefFiltrage();
			RxBuffer[0] = 'Z';
			RxBuffer[1] = 'Z';
			RxBuffer[2] = 0x00;
		}

		
		if(InputBuffer[0] == 0x21)			// Recuperation des coef Moyenneur 
		{
			i = InputBuffer[1] - 9;
			CoeffMoy[i] = InputBuffer[2] - 10;								// Coef Amplificateur
			CoeffMoy[i] = CoeffMoy[i] * 4096;
			t = InputBuffer[3] - 10;
			t = t * 64;
			CoeffMoy[i] = CoeffMoy[i] + t;								// Coef Amplificateur
			t = InputBuffer[4] - 10;
			CoeffMoy[i] = CoeffMoy[i] + t;
			//BatInitCoefFiltrage();
			RxBuffer[0] = 'Z';
			RxBuffer[1] = 'Z';
			RxBuffer[2] = 0x00;
		}



		InputBuffer[0] = 0x00;
		EnvoiData = 1;
	}
		 
	if(EnvoiData == 1)
	{
		if(mUSBUSARTIsTxTrfReady())
		{
			putsUSBUSART(RxBuffer);
			EnvoiData = 0;
		}
	}
}
//**********************************************************************************************






//**********************************************************************************************
// Lecture des registres du chargeur
//**********************************************************************************************
void LectureRegistres(void)
{
    static unsigned char i, n;
	
	
	if(Charge == 0x1)				// Lecture Mode Chargeur
	{
		RxBuffer[0] = 'C';
	}
	else
	{
		RxBuffer[0] = 'D';
	}
	
	if(ADCON1bits.VCFG0 == 0)				// Lecture de la reference de tension pour ADC
	{
		RxBuffer[1] = '5';
	}
	else
	{
		RxBuffer[1] = '4';
	}
	
	n = NbTotalOctetUSB + 2;
	for(i=2; i<= n; i++)
	{
		RxBuffer[i] = ResultatConv[i-2];
	}
	
	n = n + 1;
	RxBuffer[n] = 0x00;
}
//**********************************************************************************************





//**********************************************************************************************
// Sauvegarde en EEPROM  des valeurs de correction pour Tension
//**********************************************************************************************
void SauvegardeEnEeprom(unsigned char Valeur[8])
{
    static unsigned int 	Correction, Correction1, Correction2;
	
	
	if(Valeur[1] == 1)			// Sauvegarde de CorrectionAlim15
	{
		Correction 			= Valeur[2] - 0x30;
		Correction 			= Correction << 12;
				
		Correction1 		= Valeur[3] - 0x30;
		Correction1 		= Correction1 << 8;
		Correction 			= Correction + Correction1;
				
		Correction1 		= Valeur[4] - 0x30;
		Correction1 		= Correction1 << 4;
		Correction 			= Correction + Correction1;

		Correction1 		= Valeur[5] - 0x30;
		Correction 			= Correction + Correction1;

		CorrectionAlim15 	= Correction;
				
		Correction1 = Valeur[2] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[3] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAlim15H,Correction1);
				
		Correction1 = Valeur[4] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[5] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAlim15B,Correction1);
	}

	if(Valeur[1] == 2)			// Sauvegarde de CorrectionAccu4
	{
		Correction 			= Valeur[2] - 0x30;
		Correction 			= Correction << 12;
				
		Correction1 		= Valeur[3] - 0x30;
		Correction1 		= Correction1 << 8;
		Correction 			= Correction + Correction1;
				
		Correction1 		= Valeur[4] - 0x30;
		Correction1 		= Correction1 << 4;
		Correction 			= Correction + Correction1;

		Correction1 		= Valeur[5] - 0x30;
		Correction 			= Correction + Correction1;

		CorrectionAccu4 	= Correction;
				
		Correction1 = Valeur[2] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[3] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu4H,Correction1);
				
		Correction1 = Valeur[4] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[5] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu4B,Correction1);
	}

	if(Valeur[1] == 3)			// Sauvegarde de CorrectionAccu3
	{
		Correction 			= Valeur[2] - 0x30;
		Correction 			= Correction << 12;
				
		Correction1 		= Valeur[3] - 0x30;
		Correction1 		= Correction1 << 8;
		Correction 			= Correction + Correction1;
				
		Correction1 		= Valeur[4] - 0x30;
		Correction1 		= Correction1 << 4;
		Correction 			= Correction + Correction1;

		Correction1 		= Valeur[5] - 0x30;
		Correction 			= Correction + Correction1;

		CorrectionAccu3 	= Correction;
				
		Correction1 = Valeur[2] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[3] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu3H,Correction1);
				
		Correction1 = Valeur[4] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[5] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu3B,Correction1);
	}

	if(Valeur[1] == 4)			// Sauvegarde de CorrectionAccu2
	{
		Correction 			= Valeur[2] - 0x30;
		Correction 			= Correction << 12;
				
		Correction1 		= Valeur[3] - 0x30;
		Correction1 		= Correction1 << 8;
		Correction 			= Correction + Correction1;
				
		Correction1 		= Valeur[4] - 0x30;
		Correction1 		= Correction1 << 4;
		Correction 			= Correction + Correction1;

		Correction1 		= Valeur[5] - 0x30;
		Correction 			= Correction + Correction1;

		CorrectionAccu2 	= Correction;
				
		Correction1 = Valeur[2] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[3] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu2H,Correction1);
				
		Correction1 = Valeur[4] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[5] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu2B,Correction1);
	}

	if(Valeur[1] == 5)			// Sauvegarde de CorrectionAccu1
	{
		Correction 			= Valeur[2] - 0x30;
		Correction 			= Correction << 12;
				
		Correction1 		= Valeur[3] - 0x30;
		Correction1 		= Correction1 << 8;
		Correction 			= Correction + Correction1;
				
		Correction1 		= Valeur[4] - 0x30;
		Correction1 		= Correction1 << 4;
		Correction 			= Correction + Correction1;

		Correction1 		= Valeur[5] - 0x30;
		Correction 			= Correction + Correction1;

		CorrectionAccu1 	= Correction;
				
		Correction1 = Valeur[2] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[3] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu1H,Correction1);
				
		Correction1 = Valeur[4] - 0x30;
		Correction1 = Correction1 << 4;
		Correction2 = Valeur[5] - 0x30;
		Correction1 = Correction1 + Correction2;
		Ecrit_EEPROM(AdrAccu1B,Correction1);
	}

}
//**********************************************************************************************








//**********************************************************************************************
// Lecture en EEPROM  des valeurs de correction pour Tension
//**********************************************************************************************
void LectureEnEeprom(void)
{
	static unsigned char i;
	
	i			= Lit_EEPROM(AdrAlim15H) >> 4;
	i			= i + 0x30;
	RxBuffer[0] = i;
	RxBuffer[1] = (Lit_EEPROM(AdrAlim15H) & 0x0f) + 0x30;
			
	i			= Lit_EEPROM(AdrAlim15B) >> 4;
	i			= i + 0x30;
	RxBuffer[2] = i;
	RxBuffer[3] = (Lit_EEPROM(AdrAlim15B) & 0x0f) + 0x30;
			
	i			= Lit_EEPROM(AdrAccu4H) >> 4;
	i			= i + 0x30;
	RxBuffer[4] = i;
	RxBuffer[5] = (Lit_EEPROM(AdrAccu4H) & 0x0f) + 0x30;
	
	i			= Lit_EEPROM(AdrAccu4B) >> 4;
	i			= i + 0x30;
	RxBuffer[6] = i;
	RxBuffer[7] = (Lit_EEPROM(AdrAccu4B) & 0x0f) + 0x30;
	
	i			= Lit_EEPROM(AdrAccu3H) >> 4;
	i			= i + 0x30;
	RxBuffer[8] = i;
	RxBuffer[9] = (Lit_EEPROM(AdrAccu3H) & 0x0f) + 0x30;

	i			= Lit_EEPROM(AdrAccu3B) >> 4;
	i			= i + 0x30;
	RxBuffer[10] = i;
	RxBuffer[11] = (Lit_EEPROM(AdrAccu3B) & 0x0f) + 0x30;
			
	i			= Lit_EEPROM(AdrAccu2H) >> 4;
	i			= i + 0x30;
	RxBuffer[12] = i;
	RxBuffer[13] = (Lit_EEPROM(AdrAccu2H) & 0x0f) + 0x30;

	i			= Lit_EEPROM(AdrAccu2B) >> 4;
	i			= i + 0x30;
	RxBuffer[14] = i;
	RxBuffer[15] = (Lit_EEPROM(AdrAccu2B) & 0x0f) + 0x30;
			
	i			= Lit_EEPROM(AdrAccu1H) >> 4;
	i			= i + 0x30;
	RxBuffer[16] = i;
	RxBuffer[17] = (Lit_EEPROM(AdrAccu1H) & 0x0f) + 0x30;

	i			= Lit_EEPROM(AdrAccu1B) >> 4;
	i			= i + 0x30;
	RxBuffer[18] = i;
	RxBuffer[19] = (Lit_EEPROM(AdrAccu1B) & 0x0f) + 0x30;
}
//**********************************************************************************************





//**********************************************************************************************
// Lecture des registres du chargeur
//**********************************************************************************************
void LectureCoefficient(void)
{
    static unsigned long Tmp;

			Tmp = (CoefAmplificateur >> 12);
			RxBuffer[0] = Tmp + 0x30;
			
			Tmp = (CoefAmplificateur >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[1] = Tmp + 0x30;
			
			Tmp = (CoefAmplificateur >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[2] = Tmp + 0x30;
			
			RxBuffer[3] = (CoefAmplificateur & 0x000F);
			RxBuffer[3] = RxBuffer[3] + 0x30;
			

			Tmp = (CoefMoyenneur >> 12);
			RxBuffer[4] = Tmp + 0x30;
			
			Tmp = (CoefMoyenneur >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[5] = Tmp + 0x30;
			
			Tmp = (CoefMoyenneur >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[6] = Tmp + 0x30;
			
			RxBuffer[7] = (CoefMoyenneur & 0x000F);
			RxBuffer[7] = RxBuffer[7] + 0x30;
			

			Tmp = (OffsetCharge >> 12);
			RxBuffer[8] = Tmp + 0x30;
			
			Tmp = (OffsetCharge >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[9] = Tmp + 0x30;
			
			Tmp = (OffsetCharge >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[10] = Tmp + 0x30;
			
			RxBuffer[11] = (OffsetCharge & 0x000F);
			RxBuffer[11] = RxBuffer[11] + 0x30;
			

			Tmp = (OffsetChargeElt >> 12);
			RxBuffer[12] = Tmp + 0x30;
			
			Tmp = (OffsetChargeElt >> 8);
			Tmp = (Tmp & 0x000F);
			RxBuffer[13] = Tmp + 0x30;
			
			Tmp = (OffsetChargeElt >> 4);
			Tmp = (Tmp & 0x000F);
			RxBuffer[14] = Tmp + 0x30;
			
			RxBuffer[15] = (OffsetChargeElt & 0x000F);
			RxBuffer[15] = RxBuffer[15] + 0x30;
}
//**********************************************************************************************






//**********************************************************************************************
// Lecture des coeficient amplificateur pour le moyennage
//**********************************************************************************************
void LectureCoefAmpli(void)
{
    static unsigned char i;


	NumSauvegarde 		= 0;
	BatSauvegardeConvPourUSB(CoeffAmpl[1]);

	BatSauvegardeConvPourUSB(CoeffAmpl[2]);

	BatSauvegardeConvPourUSB(CoeffAmpl[3]);

	BatSauvegardeConvPourUSB(CoeffAmpl[4]);

	BatSauvegardeConvPourUSB(CoeffAmpl[5]);

	BatSauvegardeConvPourUSB(CoeffAmpl[6]);

	BatSauvegardeConvPourUSB(CoeffAmpl[7]);

	BatSauvegardeConvPourUSB(CoeffMoy[1]);

	BatSauvegardeConvPourUSB(CoeffMoy[2]);

	BatSauvegardeConvPourUSB(CoeffMoy[3]);

	BatSauvegardeConvPourUSB(CoeffMoy[4]);

	BatSauvegardeConvPourUSB(CoeffMoy[5]);

	BatSauvegardeConvPourUSB(CoeffMoy[6]);

	BatSauvegardeConvPourUSB(CoeffMoy[7]);

	for(i=0; i<=41; i++)
	{
		RxBuffer[i] = ResultatConv[i];
	}
	
	RxBuffer[42] = 0x00;
	RxBuffer[48] = 0x00;
}
//**********************************************************************************************



