//*****************************************************************************************
// Declaration des Entetes et variables
//*****************************************************************************************
	#include	"../h/Main.h"
//*****************************************************************************************





//**********************************************************************************
// Initialisation du Timer 0
// Permet de mesurer la dure du signal PPM
//**********************************************************************************
void InitTimer0(void)
{
	T0CONbits.T08BIT 	= 0;		// Configurer en mode 16 bits
	
	T0CONbits.T0CS 		= 0;		// Choix Oscillateur interne Priode Timer = Tcyc
	
	T0CONbits.PSA 		= 1;		// Pas de predivision
	T0CONbits.T0PS2 	= 0;
	T0CONbits.T0PS1 	= 1;
	T0CONbits.T0PS0 	= 0;		// Predivision par 8
	
	T0CONbits.TMR0ON 	= 1;		// Mise en route du Timer 0
	
	INTCONbits.TMR0IF 	= 0;		// Init du bit de depassement
	INTCON2bits.TMR0IP 	= 0;		// Interrupt non prioritaire
	INTCONbits.TMR0IE 	= 1;		// Interdiction interruption du Timer 0
}
//**********************************************************************************






//**********************************************************************************
// Initialisation pour l'acquisition du signal PPM
//**********************************************************************************
void InitAcquisitionPpm(void)
{
	InitTimer0();
	
	INTCON2bits.INTEDG0	= 0;		// Detection d'un front descendant
	INTCONbits.INT0IF	= 0;		// Initialisation du bit INT0
	INTCONbits.INT0IE	= 1;		// Autorisation de l'interruption du bit INT0
}
//**********************************************************************************






//**********************************************************************************
// Calcule la dure du signal servo moteur issu du signal PPM
//**********************************************************************************
void AcquisitionCalcule(void)
{
	static unsigned char 	SensMoteur;
	static unsigned long 	TempsMoteur;
	static unsigned int 	VitesseMoteur;
	
	if(INTCONbits.TMR0IF == 0)			// Pas de depassement donc detection de l'impulsion entre 1 et 2 ms
	{
		if((TempsPpm > TempsVitInf) & (TempsPpm < TempsVitSup))
		{
			// Detection d'une impulsion comprise entre 1 ms et 2 ms
			if(TempsPpm > (TempsVitNulle + TempsVitHyst))					// Marche avant
			{
				SensMoteur 		= 0;
				TempsMoteur 	= TempsPpm - TempsVitNulle;
				TempsMoteur 	= TempsMoteur << 10;
				TempsMoteur 	= TempsMoteur / (TempsVitSup - TempsVitNulle);
				VitesseMoteur 	= TempsMoteur;
			}
			else											
			{
				if(TempsPpm < (TempsVitNulle - TempsVitHyst))				// Marche arriere
				{
					SensMoteur 		= 1;
					TempsMoteur 	= TempsVitNulle - TempsPpm;
					TempsMoteur 	= TempsMoteur << 10;
					TempsMoteur 	= TempsMoteur / (TempsVitNulle - TempsVitInf);
					VitesseMoteur 	= TempsMoteur;
				}
				else														// Vitesse Nulle
				{
					VitesseMoteur 	= 0;
				}
			}
			VitessePwm(SensMoteur, VitesseMoteur);			// Modification du PWM
		}
		else
		{
			VitesseMoteur 	= 0;
		}
	}
	else							// Detection de l'impulsion de synchro
	{
		INTCONbits.TMR0IF 		= 0;		// Init du bit de depassement
	}
}
//**********************************************************************************


