//*****************************************************************************************
// Declaration des Entetes et variables
//*****************************************************************************************
	#include	"../h/Main.h"
//*****************************************************************************************









//**********************************************************************************
// Configuration du convetisseur Analogique Numerique
//**********************************************************************************
void InitAdc(void)
{
	// Choix des tensions de reference
	ADCON0bits.VCFG1 			= 0;				// Vref- = GND
	ADCON0bits.VCFG0 			= 0;				// Vref+ = VDD

	// Realisation du temps Tad = 1.6 s avec quartz 10 MHz et PLL
	ADCON2bits.ADCS2 			= 1;
	ADCON2bits.ADCS1 			= 1;
	ADCON2bits.ADCS0 			= 0;				// Fosc/64 = 40 MHz / 64 = 1.6 s
	
	// Temps d'acquisition
	ADCON2bits.ACQT2 			= 1;
	ADCON2bits.ACQT1 			= 0;
	ADCON2bits.ACQT0 			= 0;				// Temps acquisition = 8 Tad

	ADCON2bits.ADFM 			= 1;				// Justification  droite du resultat de conversion
	
	NumVoieAConvertir			= 0;				// Init de la premiere voie de conversion AN
	
	ADCON0bits.ADON 			= 1;				// Mise en route du convertisseur
	
	PIR1bits.ADIF 				= 0;				// Init du bit de depassement
	IPR1bits.ADIP 				= 0;				// Interrupt non prioritaire
	PIE1bits.ADIE 				= 0;				// Interdiction interruption du convertisseur AN
}
//**********************************************************************************



//**********************************************************************************
// Slection de la voie de conversion
//**********************************************************************************
void SelectionVoieAdc(unsigned char NumVoieConversion)
{
	switch(NumVoieConversion)
	{
		case 0:										// Selection de la voie 0
		{
			ADCON0bits.CHS2 	= 0;
			ADCON0bits.CHS1 	= 0;
			ADCON0bits.CHS0 	= 0;
			break;
		}	
		case 1:										// Selection de la voie 1
		{
			ADCON0bits.CHS2 	= 0;
			ADCON0bits.CHS1 	= 0;
			ADCON0bits.CHS0 	= 1;
			break;
		}	
		case 2:										// Selection de la voie 2
		{
			ADCON0bits.CHS2 	= 0;
			ADCON0bits.CHS1 	= 1;
			ADCON0bits.CHS0 	= 0;
			break;
		}	
		case 3:										// Selection de la voie 3
		{
			ADCON0bits.CHS2 	= 0;
			ADCON0bits.CHS1 	= 1;
			ADCON0bits.CHS0 	= 1;
			break;
		}	
		case 4:										// Selection de la voie 4
		{	
			ADCON0bits.CHS2 	= 1;
			ADCON0bits.CHS1 	= 0;
			ADCON0bits.CHS0 	= 0;
			break;
		}	
		case 5:										// Selection de la voie 5
		{
			ADCON0bits.CHS2 	= 1;
			ADCON0bits.CHS1 	= 0;
			ADCON0bits.CHS0 	= 1;
			break;
		}	
		case 6:										// Selection de la voie 6
		{
			ADCON0bits.CHS2 	= 1;
			ADCON0bits.CHS1 	= 1;
			ADCON0bits.CHS0 	= 0;
			break;
		}	
		case 7:										// Selection de la voie 7
		{
			ADCON0bits.CHS2 	= 1;
			ADCON0bits.CHS1 	= 1;
			ADCON0bits.CHS0 	= 1;
			break;
		}	
		default:									// Selection voie 0 par defaut
			ADCON0bits.CHS2 	= 0;
			ADCON0bits.CHS1 	= 0;
			ADCON0bits.CHS0 	= 0;
			break;	
	}
}
//**********************************************************************************







//**********************************************************************************
// Recuperation de la conversion AN
//**********************************************************************************
void RecupereConversionAdc(void)
{
	switch(NumVoieAConvertir)
	{
		case 0:													// Valeur crete du courant Moteur
		{
			CourantMot			= ADRESH;
			CourantMot			= CourantMot << 8;
			CourantMot			= CourantMot + ADRESL;
			
			if(CourantMot < OffsetCourant)		
			{
				Imoteur			= OffsetCourant - CourantMot;
			}
			else
			{
				Imoteur			= CourantMot - OffsetCourant;
			}
			
			Imoteur				= Imoteur / 3;
			ConversionHexaDecimal(Imoteur);						// Convertie Hexa en Decimal
			
			OctetAEmettre[6]	= HexaDecimal[3] + 0x70;
			OctetAEmettre[5]	= HexaDecimal[2] + 0x60;
			OctetAEmettre[4]	= HexaDecimal[1] + 0x50;
			
			NumVoieAConvertir	= 1;
			PIE1bits.ADIE 		= 1;							// Autorisation interruption du convertisseur AN
			break;
		}	
		case 1:													// Valeur de la tension de Bat 1
		{
			TensionBat2			= ADRESH;
			TensionBat2			= TensionBat2 << 8;
			TensionBat2			= TensionBat2 + ADRESL;
			
			Vbat				= TensionBat2 * 500;			// Tension corrige de la batterie en tenant
			Vbat 				= Vbat / 256;					// compte du pont diviseur de tension R8 - R9
			ConversionHexaDecimal(Vbat);						// Convertie Hexa en Decimal
			
			OctetAEmettre[3]	= HexaDecimal[3] + 0x40;
			OctetAEmettre[2]	= HexaDecimal[2] + 0x30;
			OctetAEmettre[1]	= HexaDecimal[1] + 0x20;
			
			NumVoieAConvertir	= 2;
			break;
		}	
		case 2:													// Valeur de la temperature du MOS 1
		{
			TemperatureMos1		= ADRESH;
			TemperatureMos1		= TemperatureMos1 << 8;
			TemperatureMos1		= TemperatureMos1 + ADRESL;
			
			TemperatureMos1 	= TemperatureMos1 / 2;
			ConversionHexaDecimal(TemperatureMos1);				// Convertie Hexa en Decimal
			
			OctetAEmettre[9]	= HexaDecimal[3] + 0xA0;
			OctetAEmettre[8]	= HexaDecimal[2] + 0x90;
			OctetAEmettre[7]	= HexaDecimal[1] + 0x80;
			
			NumVoieAConvertir	= 3;
			break;
		}	
		case 3:													// Valeur de la temperature du MOS 2
		{
			TemperatureMos2		= ADRESH;
			TemperatureMos2		= TemperatureMos2 << 8;
			TemperatureMos2		= TemperatureMos2 + ADRESL;
			
			TemperatureMos2 	= TemperatureMos2 / 2;
			ConversionHexaDecimal(TemperatureMos2);				// Convertie Hexa en Decimal
			
			OctetAEmettre[12]	= HexaDecimal[3] + 0xD0;
			OctetAEmettre[11]	= HexaDecimal[2] + 0xC0;
			OctetAEmettre[10]	= HexaDecimal[1] + 0xB0;
			
			NumVoieAConvertir	= 0;
			PIE1bits.ADIE 		= 0;				// Interdiction interruption du convertisseur AN
			break;
		}	
		default:												// dans tous les autres cas
		{
			NumVoieAConvertir	= 0;
			break;
		}	
	}
	SelectionVoieAdc(NumVoieAConvertir);						// Prepare la prochaine conversion AN
}
//**********************************************************************************






//**********************************************************************************
// Test pour commencer la conversion AN
//**********************************************************************************
void TestePwm(void)
{
	if((TMR2 > CCPR1H) & (TestConv == 0))
	{
		ADCON0bits.GO		= 1;						// Declenchement de la conversion AN
		TestConv 			= 1;
	}
	
	if((TMR2 > 0) & (TMR2 <= CCPR1H))
	{
		TestConv 			= 0;
	}
}
//**********************************************************************************




